@@ -36,13 +36,14 @@ def results_vis(f_dict: Dict[str,Forecaster],plot_type: str='forecast', print_at
 
     def display_user_selections(ts_selection,mo_selection,lv_selection,ci_selection,me_selection):
         selected_data = f_dict[ts_selection]
-        print(ts_selection)
         if plot_type == 'forecast':
             selected_data.plot(models=f'top_{mo_selection}',order_by=me_selection,level=lv_selection,
                                print_attr=print_attr,ci=ci_selection)
         else:
             selected_data.plot_test_set(models=f'top_{mo_selection}',order_by=me_selection,include_train=include_train,level=lv_selection,
                                         ci=ci_selection)
+        plt.title(ts_selection + ' Forecast Results', size = 16)
+        plt.show()
             
     def on_button_clicked(b):
         mo_selection = mo_dd.value
